Index: /AE/Installer/trunk/source/aeinstallerapp.cpp
===================================================================
--- /AE/Installer/trunk/source/aeinstallerapp.cpp	(revision 384)
+++ /AE/Installer/trunk/source/aeinstallerapp.cpp	(revision 385)
@@ -138,4 +138,5 @@
 
 	//anything after this is done after the window appears...
+
 	if ( !exists("../GameDataFolder") )
 	{
Index: /AE/Installer/trunk/source/main_window.cpp
===================================================================
--- /AE/Installer/trunk/source/main_window.cpp	(revision 384)
+++ /AE/Installer/trunk/source/main_window.cpp	(revision 385)
@@ -288,6 +288,9 @@
 			//printf(Step_x_x,"Step %d/%d: reimporting level", parts_done + 1, 7 + 2 * num_levels); setStatusArea((string)Step_x_x + levels[i] + (string)"_Final.dat");
 			setStatusArea("Step " + lexical_cast<std::string>(parts_done + 1) + "/" + lexical_cast<std::string>(total_steps) + " reimporting level" + levels[i]+"_Final.oni");
-			system( (strOniSplit + " " + strImportOption + " ../GameDataFolder/level" + levels[i] + "_Final packages/VanillaDats/level" + levels[i] + "_Final/level"
-				+ levels[i] + "_Final/level" + levels[i] + "_Final.oni >> Globalize.log").c_str());
+			logfile << (strOniSplit + " " + strImportOption + " ../GameDataFolder/level" + levels[i] + "_Final packages/VanillaDats/level" + levels[i] + "_Final/level" 
+				+ levels[i] + "_Final/level" + levels[i] + "_Final.oni >> Globalize.log").c_str() << '\n';
+			string sys_str = (strOniSplit + " " + strImportOption + " ../GameDataFolder/level" + levels[i] + "_Final packages/VanillaDats/level" + levels[i] + "_Final/level"
+				+ levels[i] + "_Final/level" + levels[i] + "_Final.oni >> Globalize2.log");
+				system(sys_str.c_str() );
 			setProgressBar( (int)(1000 * (float)(parts_done) / (float)(total_steps) ));
 			parts_done++;
@@ -636,6 +639,5 @@
 				if ( is_directory( dir_itr->status() ) )
 				{
-					importCommand = strOniSplit + " " + strImportOption + " " + vanilla_dir.string() + dir_itr->path().filename() + " " + "../GameDataFolder/" + dir_itr->path().filename()
-						+ ".dat";
+					importCommand = strOniSplit + " " + strImportOption + " " + vanilla_dir.string() + dir_itr->path().filename() + " ";
 					for (int i = 0; i < installedMods.size(); ++i) {
 						if (exists("packages/" + installedMods[i] + "/oni/" + dir_itr->path().filename()  ))
@@ -798,5 +800,5 @@
 
 ////@begin includes
-#include "about_window.h"
+#include "about.h"
 ////@end includes
 
@@ -804,5 +806,6 @@
 
 ////@begin XPM images
-#include "redo.xpm"
+#include "aelogosmall.xpm"
+#include "undo.xpm"
 #include "fileopen.xpm"
 #include "filesaveas.xpm"
@@ -827,34 +830,34 @@
 
 ////@begin MainWindow event table entries
-EVT_CHECKBOX( SelectAll_Checkbox, MainWindow::OnSelectAllCheckboxClick )
-
-EVT_BUTTON( Refresh_Button, MainWindow::OnRefreshButtonClick )
-
-EVT_LISTBOX( Mods_CheckboxList1, MainWindow::OnModsCheckboxList1Selected )
-EVT_CHECKLISTBOX( Mods_CheckboxList1, MainWindow::OnModsCheckboxList1Toggled )
-
-EVT_UPDATE_UI( ID_STATUSBAR, MainWindow::OnStatusbarUpdate )
-
-EVT_BUTTON( Install_Button, MainWindow::OnInstallButtonClick )
-
-EVT_RADIOBUTTON( Sep_RadioButton, MainWindow::OnSepRadioButtonSelected )
-
-EVT_RADIOBUTTON( NoSep_RadioButton, MainWindow::OnNoSepRadioButtonSelected )
-
-EVT_RADIOBUTTON( Separated_RadioButton, MainWindow::OnSeparatedRadioButtonSelected )
-
-EVT_RADIOBUTTON( Complete_RadioButton, MainWindow::OnCompleteRadioButtonSelected )
-
-EVT_BUTTON( ReGlobalize_Button, MainWindow::OnReGlobalizeButtonClick )
-
-EVT_MENU( wxID_LOAD, MainWindow::OnLoadClick )
-
-EVT_MENU( wxID_SAVE, MainWindow::OnSaveClick )
-
-EVT_MENU( wxID_EXIT, MainWindow::OnExitClick )
-
-EVT_MENU( wxID_OPTIONS, MainWindow::OnOptionsClick )
-
-EVT_MENU( wxID_ABOUT, MainWindow::OnAboutClick )
+    EVT_CHECKBOX( SelectAll_Checkbox, MainWindow::OnSelectAllCheckboxClick )
+
+    EVT_BUTTON( Refresh_Button, MainWindow::OnRefreshButtonClick )
+
+    EVT_LISTBOX( Mods_CheckboxList1, MainWindow::OnModsCheckboxList1Selected )
+    EVT_CHECKLISTBOX( Mods_CheckboxList1, MainWindow::OnModsCheckboxList1Toggled )
+
+    EVT_UPDATE_UI( ID_STATUSBAR, MainWindow::OnStatusbarUpdate )
+
+    EVT_BUTTON( Install_Button, MainWindow::OnInstallButtonClick )
+
+    EVT_RADIOBUTTON( Sep_RadioButton, MainWindow::OnSepRadioButtonSelected )
+
+    EVT_RADIOBUTTON( NoSep_RadioButton, MainWindow::OnNoSepRadioButtonSelected )
+
+    EVT_RADIOBUTTON( Seperated_RadioButton, MainWindow::OnSeperatedRadioButtonSelected )
+
+    EVT_RADIOBUTTON( Complete_RadioButton, MainWindow::OnCompleteRadioButtonSelected )
+
+    EVT_BUTTON( ReGlobalize_Button, MainWindow::OnReGlobalizeButtonClick )
+
+    EVT_MENU( wxID_LOAD, MainWindow::OnLoadClick )
+
+    EVT_MENU( wxID_SAVE, MainWindow::OnSaveClick )
+
+    EVT_MENU( wxID_EXIT, MainWindow::OnExitClick )
+
+    EVT_MENU( wxID_OPTIONS, MainWindow::OnOptionsClick )
+
+    EVT_MENU( wxID_ABOUT, MainWindow::OnAboutClick )
 
 ////@end MainWindow event table entries
@@ -886,11 +889,9 @@
 {
 	////@begin MainWindow creation
-	wxFrame::Create( parent, id, caption, pos, size, style );
-
-	CreateControls();
-	SetIcon(GetIconResource(wxT("oni_special.ico")));
-	Centre();
-
-
+    wxFrame::Create( parent, id, caption, pos, size, style );
+
+    CreateControls();
+    SetIcon(GetIconResource(wxT("aelogosmall.png")));
+    Centre();
 	////@end MainWindow creation
 	return true;
@@ -916,20 +917,20 @@
 {
 	////@begin MainWindow member initialisation
-	MainSplitter = NULL;
-	SelectAll = NULL;
-	RefreshButton = NULL;
-	Mods_CheckboxList = NULL;
-	titleText = NULL;
-	creatorText = NULL;
-	descriptionText = NULL;
-	StatusArea = NULL;
-	ProgressBar = NULL;
-	InstallButton = NULL;
-	OptionsPanel = NULL;
-	SepRadio = NULL;
-	NoSepRadio = NULL;
-	SeparatedRadio = NULL;
-	CompleteRadio = NULL;
-	ReglobalizeButton = NULL;
+    MainSplitter = NULL;
+    SelectAll = NULL;
+    RefreshButton = NULL;
+    Mods_CheckboxList = NULL;
+    titleText = NULL;
+    creatorText = NULL;
+    descriptionText = NULL;
+    StatusArea = NULL;
+    ProgressBar = NULL;
+    InstallButton = NULL;
+    OptionsPanel = NULL;
+    SepRadio = NULL;
+    NoSepRadio = NULL;
+    SeperatedRadio = NULL;
+    CompleteRadio = NULL;
+    ReglobalizeButton = NULL;
 	////@end MainWindow member initialisation
 
@@ -946,175 +947,172 @@
 {    
 	////@begin MainWindow content construction
-	// Generated by DialogBlocks, 31/05/2009 19:03:55 (unregistered)
-
-	MainWindow* itemFrame1 = this;
-
-	wxMenuBar* menuBar = new wxMenuBar;
-	wxMenu* itemMenu37 = new wxMenu;
-	{
-		wxMenuItem* menuItem = new wxMenuItem(itemMenu37, wxID_LOAD, _("&Load Configuration..."), wxEmptyString, wxITEM_NORMAL);
-		wxBitmap bitmap(itemFrame1->GetBitmapResource(wxT("fileopen.xpm")));
-		menuItem->SetBitmap(bitmap);
-		itemMenu37->Append(menuItem);
-	}
-	{
-		wxMenuItem* menuItem = new wxMenuItem(itemMenu37, wxID_SAVE, _("&Save Configuration..."), wxEmptyString, wxITEM_NORMAL);
-		wxBitmap bitmap(itemFrame1->GetBitmapResource(wxT("filesaveas.xpm")));
-		menuItem->SetBitmap(bitmap);
-		itemMenu37->Append(menuItem);
-	}
-	itemMenu37->AppendSeparator();
-	{
-		wxMenuItem* menuItem = new wxMenuItem(itemMenu37, wxID_EXIT, _("Exit"), wxEmptyString, wxITEM_NORMAL);
-		wxBitmap bitmap(itemFrame1->GetBitmapResource(wxT("quit.xpm")));
-		menuItem->SetBitmap(bitmap);
-		itemMenu37->Append(menuItem);
-	}
-	menuBar->Append(itemMenu37, _("&File"));
-	wxMenu* itemMenu42 = new wxMenu;
-	itemMenu42->Append(wxID_OPTIONS, _("Show Advanced Options..."), wxEmptyString, wxITEM_CHECK);
-	menuBar->Append(itemMenu42, _("Options"));
-	wxMenu* itemMenu44 = new wxMenu;
-	itemMenu44->Append(wxID_HELP, _("Help"), wxEmptyString, wxITEM_NORMAL);
-	itemMenu44->Append(wxID_ABOUT, _("About"), wxEmptyString, wxITEM_NORMAL);
-	menuBar->Append(itemMenu44, _("Help"));
-	itemFrame1->SetMenuBar(menuBar);
-	
-	wxBoxSizer* itemBoxSizer2 = new wxBoxSizer(wxVERTICAL);
-	itemFrame1->SetSizer(itemBoxSizer2);
-
-	MainSplitter = new wxSplitterWindow( itemFrame1, ID_SPLITTERWINDOW, wxDefaultPosition, wxSize(100, 100), wxSP_LIVE_UPDATE|wxNO_BORDER );
-	MainSplitter->SetMinimumPaneSize(150);
-	MainSplitter->SetName(_T("MainSplitter"));
-
-	wxPanel* itemPanel4 = new wxPanel( MainSplitter, ID_PANEL, wxDefaultPosition, wxDefaultSize, wxSUNKEN_BORDER|wxTAB_TRAVERSAL );
-	wxBoxSizer* itemBoxSizer5 = new wxBoxSizer(wxVERTICAL);
-	itemPanel4->SetSizer(itemBoxSizer5);
-
-	wxBoxSizer* itemBoxSizer6 = new wxBoxSizer(wxHORIZONTAL);
-	itemBoxSizer5->Add(itemBoxSizer6, 0, wxGROW|wxALL, 0);
-	SelectAll = new wxCheckBox( itemPanel4, SelectAll_Checkbox, _("Select All/None"), wxDefaultPosition, wxDefaultSize, wxCHK_3STATE );
-	SelectAll->SetValue(false);
-	SelectAll->SetName(_T("SelectAll_Checkbox"));
-	itemBoxSizer6->Add(SelectAll, 0, wxALIGN_CENTER_VERTICAL|wxALL, 5);
-
-	RefreshButton = new wxBitmapButton( itemPanel4, Refresh_Button, itemFrame1->GetBitmapResource(wxT("redo.xpm")), wxDefaultPosition, wxDefaultSize, wxBU_AUTODRAW );
-	RefreshButton->SetName(_T("RefreshButton"));
-	itemBoxSizer6->Add(RefreshButton, 0, wxALIGN_CENTER_VERTICAL|wxLEFT|wxTOP|wxBOTTOM, 5);
-
-	wxArrayString Mods_CheckboxListStrings;
-	Mods_CheckboxList = new wxCheckListBox( itemPanel4, Mods_CheckboxList1, wxDefaultPosition, wxDefaultSize, Mods_CheckboxListStrings, wxLB_HSCROLL );
-	Mods_CheckboxList->SetName(_T("Mods_CheckboxList"));
-	itemBoxSizer5->Add(Mods_CheckboxList, 1, wxGROW|wxALL, 0);
-
-	wxPanel* itemPanel10 = new wxPanel( MainSplitter, DescriptionHolder_Panel, wxDefaultPosition, wxDefaultSize, wxSUNKEN_BORDER|wxTAB_TRAVERSAL );
-	itemPanel10->SetName(_T("DescriptionHolder_Panel"));
-	wxBoxSizer* itemBoxSizer11 = new wxBoxSizer(wxVERTICAL);
-	itemPanel10->SetSizer(itemBoxSizer11);
-
-	wxBoxSizer* itemBoxSizer12 = new wxBoxSizer(wxHORIZONTAL);
-	itemBoxSizer11->Add(itemBoxSizer12, 0, wxGROW|wxALL, 0);
-	wxBoxSizer* itemBoxSizer13 = new wxBoxSizer(wxVERTICAL);
-	itemBoxSizer12->Add(itemBoxSizer13, 1, wxALIGN_CENTER_VERTICAL|wxALL, 0);
-	titleText = new wxTextCtrl( itemPanel10, Title_Text, wxEmptyString, wxDefaultPosition, wxDefaultSize, wxTE_READONLY );
-	titleText->SetName(_T("Title_Text"));
-	titleText->SetBackgroundColour(wxColour(240, 240, 240));
-	itemBoxSizer13->Add(titleText, 1, wxGROW|wxLEFT, 5);
-
-	wxBoxSizer* itemBoxSizer15 = new wxBoxSizer(wxVERTICAL);
-	itemBoxSizer12->Add(itemBoxSizer15, 1, wxGROW|wxALL, 0);
-	creatorText = new wxTextCtrl( itemPanel10, Author_Text, wxEmptyString, wxDefaultPosition, wxDefaultSize, wxTE_READONLY|wxTE_RIGHT );
-	creatorText->SetName(_T("Author_Text"));
-	creatorText->SetBackgroundColour(wxColour(240, 240, 240));
-	itemBoxSizer15->Add(creatorText, 1, wxGROW|wxRIGHT, 5);
-
-	wxStaticLine* itemStaticLine17 = new wxStaticLine( itemPanel10, wxID_STATIC, wxDefaultPosition, wxDefaultSize, wxLI_HORIZONTAL );
-	itemStaticLine17->Show(false);
-	itemBoxSizer11->Add(itemStaticLine17, 0, wxGROW|wxALL, 5);
-
-	descriptionText = new wxTextCtrl( itemPanel10, Description_Text, wxEmptyString, wxDefaultPosition, wxDefaultSize, wxTE_MULTILINE|wxTE_READONLY|wxTE_RICH|wxTE_AUTO_URL );
-	descriptionText->SetName(_T("DescriptionName"));
-	descriptionText->SetBackgroundColour(wxColour(240, 240, 240));
-	itemBoxSizer11->Add(descriptionText, 1, wxGROW|wxLEFT|wxRIGHT, 5);
-
-	MainSplitter->SplitVertically(itemPanel4, itemPanel10, 150);
-	itemBoxSizer2->Add(MainSplitter, 1, wxGROW|wxALL, 0);
-
-	StatusArea = new wxStatusBar( itemFrame1, ID_STATUSBAR, 0 );
-	StatusArea->SetName(_T("StatusArea"));
-	StatusArea->SetFieldsCount(1);
-	StatusArea->SetStatusText(_("Status Area"), 0);
-	itemBoxSizer2->Add(StatusArea, 0, wxGROW|wxALL, 0);
-
-	wxBoxSizer* itemBoxSizer20 = new wxBoxSizer(wxHORIZONTAL);
-	itemBoxSizer2->Add(itemBoxSizer20, 0, wxGROW|wxALL, 0);
-
-	ProgressBar = new wxGauge( itemFrame1, ProgressBar_Gauge, 1000, wxDefaultPosition, wxSize(-1, 30), wxGA_SMOOTH );
-	ProgressBar->SetValue(0);
-	itemBoxSizer20->Add(ProgressBar, 1, wxGROW|wxALL, 0);
-
-	InstallButton = new wxButton( itemFrame1, Install_Button, _("Install!"), wxDefaultPosition, wxSize(-1, 30), 0 );
-	itemBoxSizer20->Add(InstallButton, 0, wxGROW|wxALL, 0);
-
-	wxBoxSizer* itemBoxSizer23 = new wxBoxSizer(wxVERTICAL);
-	itemBoxSizer2->Add(itemBoxSizer23, 0, wxGROW|wxALL, 0);
-
-	OptionsPanel = new wxPanel( itemFrame1, ID_PANEL1, wxDefaultPosition, wxDefaultSize, wxSUNKEN_BORDER|wxTAB_TRAVERSAL );
-	itemBoxSizer2->Add(OptionsPanel, 0, wxGROW, 0);
-
-	wxBoxSizer* itemBoxSizer25 = new wxBoxSizer(wxHORIZONTAL);
-	OptionsPanel->SetSizer(itemBoxSizer25);
-
-	wxBoxSizer* itemBoxSizer26 = new wxBoxSizer(wxVERTICAL);
-	itemBoxSizer25->Add(itemBoxSizer26, 0, wxGROW|wxALL, 5);
-
-	SepRadio = new wxRadioButton( OptionsPanel, Sep_RadioButton, _("Sep"), wxDefaultPosition, wxDefaultSize, wxRB_GROUP );
-	SepRadio->SetValue(false);
-	if (MainWindow::ShowToolTips())
-		SepRadio->SetToolTip(_("For PC Demo and Mac"));
-	itemBoxSizer26->Add(SepRadio, 0, wxALIGN_LEFT|wxALL, 5);
-
-	NoSepRadio = new wxRadioButton( OptionsPanel, NoSep_RadioButton, _("NoSep"), wxDefaultPosition, wxDefaultSize, 0 );
-	NoSepRadio->SetValue(false);
-	if (MainWindow::ShowToolTips())
-		NoSepRadio->SetToolTip(_("For PC Retail"));
-	itemBoxSizer26->Add(NoSepRadio, 0, wxALIGN_LEFT|wxALL, 5);
-
-	wxStaticLine* itemStaticLine29 = new wxStaticLine( OptionsPanel, wxID_STATIC, wxDefaultPosition, wxDefaultSize, wxLI_VERTICAL );
-	itemBoxSizer25->Add(itemStaticLine29, 0, wxGROW|wxALL, 5);
-
-	wxBoxSizer* itemBoxSizer30 = new wxBoxSizer(wxVERTICAL);
-	itemBoxSizer25->Add(itemBoxSizer30, 0, wxGROW|wxALL, 5);
-
-	SeparatedRadio = new wxRadioButton( OptionsPanel, Separated_RadioButton, _("Separated Level0"), wxDefaultPosition, wxDefaultSize, wxRB_GROUP );
-	SeparatedRadio->SetValue(false);
-	SeparatedRadio->SetName(_T("Separated_RadioButton"));
-	itemBoxSizer30->Add(SeparatedRadio, 0, wxALIGN_LEFT|wxALL, 5);
-
-	CompleteRadio = new wxRadioButton( OptionsPanel, Complete_RadioButton, _("Complete Level0"), wxDefaultPosition, wxDefaultSize, 0 );
-	CompleteRadio->SetValue(false);
-	CompleteRadio->SetName(_T("Complete_RadioButton"));
-	itemBoxSizer30->Add(CompleteRadio, 0, wxALIGN_LEFT|wxALL, 5);
-
-	wxStaticLine* itemStaticLine33 = new wxStaticLine( OptionsPanel, wxID_STATIC, wxDefaultPosition, wxDefaultSize, wxLI_VERTICAL );
-	itemBoxSizer25->Add(itemStaticLine33, 0, wxGROW|wxALL, 5);
-
-	wxBoxSizer* itemBoxSizer34 = new wxBoxSizer(wxVERTICAL);
-	itemBoxSizer25->Add(itemBoxSizer34, 0, wxALIGN_CENTER_VERTICAL|wxALL, 5);
-
-	ReglobalizeButton = new wxButton( OptionsPanel, ReGlobalize_Button, _("Reglobalize"), wxDefaultPosition, wxDefaultSize, 0 );
-	ReglobalizeButton->SetName(_T("Reglobalize_Button"));
-	itemBoxSizer34->Add(ReglobalizeButton, 0, wxGROW|wxALL, 5);
-
-	// Connect events and objects
-	Mods_CheckboxList->Connect(Mods_CheckboxList1, wxEVT_CREATE, wxWindowCreateEventHandler(MainWindow::ModList_OnCreate), NULL, this);
+    MainWindow* itemFrame1 = this;
+
+    wxMenuBar* menuBar = new wxMenuBar;
+    wxMenu* itemMenu37 = new wxMenu;
+    {
+        wxMenuItem* menuItem = new wxMenuItem(itemMenu37, wxID_LOAD, _("&Load Configuration..."), wxEmptyString, wxITEM_NORMAL);
+        wxBitmap bitmap(itemFrame1->GetBitmapResource(wxT("fileopen.xpm")));
+        menuItem->SetBitmap(bitmap);
+        itemMenu37->Append(menuItem);
+    }
+    {
+        wxMenuItem* menuItem = new wxMenuItem(itemMenu37, wxID_SAVE, _("&Save Configuration..."), wxEmptyString, wxITEM_NORMAL);
+        wxBitmap bitmap(itemFrame1->GetBitmapResource(wxT("filesaveas.xpm")));
+        menuItem->SetBitmap(bitmap);
+        itemMenu37->Append(menuItem);
+    }
+    itemMenu37->AppendSeparator();
+    {
+        wxMenuItem* menuItem = new wxMenuItem(itemMenu37, wxID_EXIT, _("Exit"), wxEmptyString, wxITEM_NORMAL);
+        wxBitmap bitmap(itemFrame1->GetBitmapResource(wxT("quit.xpm")));
+        menuItem->SetBitmap(bitmap);
+        itemMenu37->Append(menuItem);
+    }
+    menuBar->Append(itemMenu37, _("&File"));
+    wxMenu* itemMenu42 = new wxMenu;
+    itemMenu42->Append(wxID_OPTIONS, _("Show Advanced Options..."), wxEmptyString, wxITEM_CHECK);
+    menuBar->Append(itemMenu42, _("Options"));
+    wxMenu* itemMenu44 = new wxMenu;
+    itemMenu44->Append(wxID_ABOUT, _("About"), wxEmptyString, wxITEM_NORMAL);
+    menuBar->Append(itemMenu44, _("Help"));
+    itemFrame1->SetMenuBar(menuBar);
+
+    wxBoxSizer* itemBoxSizer2 = new wxBoxSizer(wxVERTICAL);
+    itemFrame1->SetSizer(itemBoxSizer2);
+
+    MainSplitter = new wxSplitterWindow( itemFrame1, ID_SPLITTERWINDOW, wxDefaultPosition, wxSize(100, 100), wxSP_LIVE_UPDATE|wxNO_BORDER );
+    MainSplitter->SetMinimumPaneSize(1);
+    MainSplitter->SetName(_T("MainSplitter"));
+
+    wxPanel* itemPanel4 = new wxPanel( MainSplitter, ID_PANEL, wxDefaultPosition, wxDefaultSize, wxSUNKEN_BORDER|wxTAB_TRAVERSAL );
+    wxBoxSizer* itemBoxSizer5 = new wxBoxSizer(wxVERTICAL);
+    itemPanel4->SetSizer(itemBoxSizer5);
+
+    wxBoxSizer* itemBoxSizer6 = new wxBoxSizer(wxHORIZONTAL);
+    itemBoxSizer5->Add(itemBoxSizer6, 0, wxGROW|wxALL, 0);
+    SelectAll = new wxCheckBox( itemPanel4, SelectAll_Checkbox, _("Select All/None"), wxDefaultPosition, wxDefaultSize, wxCHK_3STATE );
+    SelectAll->SetValue(false);
+    SelectAll->SetName(_T("SelectAll_Checkbox"));
+    itemBoxSizer6->Add(SelectAll, 0, wxALIGN_CENTER_VERTICAL|wxALL, 5);
+
+    RefreshButton = new wxBitmapButton( itemPanel4, Refresh_Button, itemFrame1->GetBitmapResource(wxT("undo.xpm")), wxDefaultPosition, wxDefaultSize, wxBU_AUTODRAW );
+    RefreshButton->SetName(_T("RefreshButton"));
+    itemBoxSizer6->Add(RefreshButton, 0, wxALIGN_CENTER_VERTICAL|wxLEFT|wxTOP|wxBOTTOM, 5);
+
+    wxArrayString Mods_CheckboxListStrings;
+    Mods_CheckboxList = new wxCheckListBox( itemPanel4, Mods_CheckboxList1, wxDefaultPosition, wxDefaultSize, Mods_CheckboxListStrings, wxLB_HSCROLL );
+    Mods_CheckboxList->SetName(_T("Mods_CheckboxList"));
+    itemBoxSizer5->Add(Mods_CheckboxList, 1, wxGROW|wxALL, 0);
+
+    wxPanel* itemPanel10 = new wxPanel( MainSplitter, DescriptionHolder_Panel, wxDefaultPosition, wxDefaultSize, wxSUNKEN_BORDER|wxTAB_TRAVERSAL );
+    itemPanel10->SetName(_T("DescriptionHolder_Panel"));
+    wxBoxSizer* itemBoxSizer11 = new wxBoxSizer(wxVERTICAL);
+    itemPanel10->SetSizer(itemBoxSizer11);
+
+    wxBoxSizer* itemBoxSizer12 = new wxBoxSizer(wxHORIZONTAL);
+    itemBoxSizer11->Add(itemBoxSizer12, 0, wxGROW|wxALL, 0);
+    wxBoxSizer* itemBoxSizer13 = new wxBoxSizer(wxVERTICAL);
+    itemBoxSizer12->Add(itemBoxSizer13, 1, wxALIGN_CENTER_VERTICAL|wxALL, 0);
+    titleText = new wxTextCtrl( itemPanel10, Title_Text, wxEmptyString, wxDefaultPosition, wxDefaultSize, wxTE_READONLY );
+    titleText->SetName(_T("Title_Text"));
+    titleText->SetBackgroundColour(wxColour(240, 240, 240));
+    itemBoxSizer13->Add(titleText, 1, wxGROW|wxLEFT, 5);
+
+    wxBoxSizer* itemBoxSizer15 = new wxBoxSizer(wxVERTICAL);
+    itemBoxSizer12->Add(itemBoxSizer15, 1, wxGROW|wxALL, 0);
+    creatorText = new wxTextCtrl( itemPanel10, Author_Text, wxEmptyString, wxDefaultPosition, wxDefaultSize, wxTE_READONLY|wxTE_RIGHT );
+    creatorText->SetName(_T("Author_Text"));
+    creatorText->SetBackgroundColour(wxColour(240, 240, 240));
+    itemBoxSizer15->Add(creatorText, 1, wxGROW|wxRIGHT, 5);
+
+    wxStaticLine* itemStaticLine17 = new wxStaticLine( itemPanel10, wxID_STATIC, wxDefaultPosition, wxDefaultSize, wxLI_HORIZONTAL );
+    itemStaticLine17->Show(false);
+    itemBoxSizer11->Add(itemStaticLine17, 0, wxGROW|wxALL, 5);
+
+    descriptionText = new wxTextCtrl( itemPanel10, Description_Text, wxEmptyString, wxDefaultPosition, wxDefaultSize, wxTE_MULTILINE|wxTE_READONLY|wxTE_RICH|wxTE_RICH2 );
+    descriptionText->SetName(_T("DescriptionName"));
+    descriptionText->SetBackgroundColour(wxColour(240, 240, 240));
+    itemBoxSizer11->Add(descriptionText, 1, wxGROW|wxLEFT|wxRIGHT, 5);
+
+    MainSplitter->SplitVertically(itemPanel4, itemPanel10, 200);
+    itemBoxSizer2->Add(MainSplitter, 1, wxGROW|wxALL, 0);
+
+    StatusArea = new wxStatusBar( itemFrame1, ID_STATUSBAR, 0 );
+    StatusArea->SetName(_T("StatusArea"));
+    StatusArea->SetFieldsCount(1);
+    StatusArea->SetStatusText(_("AE Installer v1.0"), 0);
+    itemBoxSizer2->Add(StatusArea, 0, wxGROW|wxALL, 0);
+
+    wxBoxSizer* itemBoxSizer20 = new wxBoxSizer(wxHORIZONTAL);
+    itemBoxSizer2->Add(itemBoxSizer20, 0, wxGROW|wxALL, 0);
+
+    ProgressBar = new wxGauge( itemFrame1, ProgressBar_Gauge, 1000, wxDefaultPosition, wxDefaultSize, wxGA_SMOOTH );
+    ProgressBar->SetValue(0);
+    itemBoxSizer20->Add(ProgressBar, 1, wxGROW|wxALL, 0);
+
+    InstallButton = new wxButton( itemFrame1, Install_Button, _("Install!"), wxDefaultPosition, wxDefaultSize, 0 );
+    itemBoxSizer20->Add(InstallButton, 0, wxGROW|wxALL, 0);
+
+    wxBoxSizer* itemBoxSizer23 = new wxBoxSizer(wxVERTICAL);
+    itemBoxSizer2->Add(itemBoxSizer23, 0, wxGROW|wxALL, 0);
+
+    OptionsPanel = new wxPanel( itemFrame1, ID_PANEL1, wxDefaultPosition, wxDefaultSize, wxSUNKEN_BORDER|wxTAB_TRAVERSAL );
+    itemBoxSizer2->Add(OptionsPanel, 0, wxGROW, 0);
+
+    wxBoxSizer* itemBoxSizer25 = new wxBoxSizer(wxHORIZONTAL);
+    OptionsPanel->SetSizer(itemBoxSizer25);
+
+    wxBoxSizer* itemBoxSizer26 = new wxBoxSizer(wxVERTICAL);
+    itemBoxSizer25->Add(itemBoxSizer26, 0, wxGROW|wxALL, 5);
+
+    SepRadio = new wxRadioButton( OptionsPanel, Sep_RadioButton, _("Sep"), wxDefaultPosition, wxDefaultSize, wxRB_GROUP );
+    SepRadio->SetValue(false);
+    if (MainWindow::ShowToolTips())
+        SepRadio->SetToolTip(_("For PC Demo and Mac"));
+    itemBoxSizer26->Add(SepRadio, 0, wxALIGN_LEFT|wxALL, 5);
+
+    NoSepRadio = new wxRadioButton( OptionsPanel, NoSep_RadioButton, _("NoSep"), wxDefaultPosition, wxDefaultSize, 0 );
+    NoSepRadio->SetValue(false);
+    if (MainWindow::ShowToolTips())
+        NoSepRadio->SetToolTip(_("For PC Retail"));
+    itemBoxSizer26->Add(NoSepRadio, 0, wxALIGN_LEFT|wxALL, 5);
+
+    wxStaticLine* itemStaticLine29 = new wxStaticLine( OptionsPanel, wxID_STATIC, wxDefaultPosition, wxDefaultSize, wxLI_VERTICAL );
+    itemBoxSizer25->Add(itemStaticLine29, 0, wxGROW|wxALL, 5);
+
+    wxBoxSizer* itemBoxSizer30 = new wxBoxSizer(wxVERTICAL);
+    itemBoxSizer25->Add(itemBoxSizer30, 0, wxGROW|wxALL, 5);
+
+    SeperatedRadio = new wxRadioButton( OptionsPanel, Seperated_RadioButton, _("Separated Level0"), wxDefaultPosition, wxDefaultSize, wxRB_GROUP );
+    SeperatedRadio->SetValue(false);
+    SeperatedRadio->SetName(_T("Seperated_RadioButton"));
+    itemBoxSizer30->Add(SeperatedRadio, 0, wxALIGN_LEFT|wxALL, 5);
+
+    CompleteRadio = new wxRadioButton( OptionsPanel, Complete_RadioButton, _("Complete Level0"), wxDefaultPosition, wxDefaultSize, 0 );
+    CompleteRadio->SetValue(false);
+    CompleteRadio->SetName(_T("Complete_RadioButton"));
+    itemBoxSizer30->Add(CompleteRadio, 0, wxALIGN_LEFT|wxALL, 5);
+
+    wxStaticLine* itemStaticLine33 = new wxStaticLine( OptionsPanel, wxID_STATIC, wxDefaultPosition, wxDefaultSize, wxLI_VERTICAL );
+    itemBoxSizer25->Add(itemStaticLine33, 0, wxGROW|wxALL, 5);
+
+    wxBoxSizer* itemBoxSizer34 = new wxBoxSizer(wxVERTICAL);
+    itemBoxSizer25->Add(itemBoxSizer34, 0, wxALIGN_CENTER_VERTICAL|wxALL, 5);
+
+    ReglobalizeButton = new wxButton( OptionsPanel, ReGlobalize_Button, _("Reglobalize"), wxDefaultPosition, wxDefaultSize, 0 );
+    ReglobalizeButton->SetName(_T("Reglobalize_Button"));
+    itemBoxSizer34->Add(ReglobalizeButton, 0, wxGROW|wxALL, 5);
+
+    // Connect events and objects
+    Mods_CheckboxList->Connect(Mods_CheckboxList1, wxEVT_CREATE, wxWindowCreateEventHandler(MainWindow::ModList_OnCreate), NULL, this);
 	////@end MainWindow content construction
 
 	if ( exists( "../../GameDataFolder/level0_Final.sep" ) ) {
-		static_cast<string>("-import:sep");
+		strImportOption = "-import:sep";
 		splitInstances = NOT_SPLIT;
 	}
 	else {
-		static_cast<string>("-import:nosep");
+		strImportOption = "-import:nosep";
 		splitInstances = SPLIT;
 	}
@@ -1131,5 +1129,5 @@
 	TheProgressBar = ProgressBar;
 	OptionsPanel->Hide();
-	if(splitInstances == SPLIT) SeparatedRadio->SetValue(true);
+	if(splitInstances == SPLIT) SeperatedRadio->SetValue(true);
 	else CompleteRadio->SetValue(true);
 
@@ -1203,26 +1201,26 @@
 	// Bitmap retrieval
 	////@begin MainWindow bitmap retrieval
-	wxUnusedVar(name);
-	if (name == _T("redo.xpm"))
-	{
-		wxBitmap bitmap(redo_xpm);
-		return bitmap;
-	}
-	else if (name == _T("fileopen.xpm"))
-	{
-		wxBitmap bitmap( fileopen_xpm);
-		return bitmap;
-	}
-	else if (name == _T("filesaveas.xpm"))
-	{
-		wxBitmap bitmap( filesaveas_xpm);
-		return bitmap;
-	}
-	else if (name == _T("quit.xpm"))
-	{
-		wxBitmap bitmap( quit_xpm);
-		return bitmap;
-	}
-	return wxNullBitmap;
+    wxUnusedVar(name);
+    if (name == _T("undo.xpm"))
+    {
+        wxBitmap bitmap( undo_xpm);
+        return bitmap;
+    }
+    else if (name == _T("fileopen.xpm"))
+    {
+        wxBitmap bitmap( fileopen_xpm);
+        return bitmap;
+    }
+    else if (name == _T("filesaveas.xpm"))
+    {
+        wxBitmap bitmap( filesaveas_xpm);
+        return bitmap;
+    }
+    else if (name == _T("quit.xpm"))
+    {
+        wxBitmap bitmap( quit_xpm);
+        return bitmap;
+    }
+    return wxNullBitmap;
 	////@end MainWindow bitmap retrieval
 }
@@ -1237,11 +1235,11 @@
 	// Icon retrieval
 	////@begin MainWindow icon retrieval
-	wxUnusedVar(name);
-	if (name == _T("oni_special.ico"))
-	{
-		//	wxIcon icon(_T("oni_special.ico"), wxBITMAP_TYPE_ICO);
-		//	return icon;
-	}
-	return wxNullIcon;
+    wxUnusedVar(name);
+    if (name == _T("aelogosmall.png"))
+    {
+        wxIcon icon(aelogosmall_xpm);
+        return icon;
+    }
+    return wxNullIcon;
 	////@end MainWindow icon retrieval
 }
@@ -1293,4 +1291,5 @@
 	if (!event.GetInt() ) {
 		OptionsPanel->Hide(); 
+		
 		this->SetSize(this->GetRect().GetWidth(), this->GetRect().GetHeight()-OptionsPanel->GetRect().GetHeight());}
 	else {
@@ -1388,6 +1387,6 @@
 {
 	////@begin wxEVT_UPDATE_UI event handler for ID_STATUSBAR in MainWindow.
-	// Before editing this code, remove the block markers.
-	event.Skip();
+    // Before editing this code, remove the block markers.
+    event.Skip();
 	////@end wxEVT_UPDATE_UI event handler for ID_STATUSBAR in MainWindow. 
 }
@@ -1401,8 +1400,8 @@
 {
 	////@begin wxEVT_COMMAND_MENU_SELECTED event handler for wxID_ABOUT in MainWindow.
-	// Before editing this code, remove the block markers.
-	About* window = new About(this);
-	int returnValue = window->ShowModal();
-	window->Destroy();
+    // Before editing this code, remove the block markers.
+    About* window = new About(this);
+    int returnValue = window->ShowModal();
+    window->Destroy();
 	////@end wxEVT_COMMAND_MENU_SELECTED event handler for wxID_ABOUT in MainWindow. 
 }
@@ -1432,11 +1431,4 @@
 * wxEVT_COMMAND_RADIOBUTTON_SELECTED event handler for Separated_RadioButton
 */
-
-void MainWindow::OnSeparatedRadioButtonSelected( wxCommandEvent& event )
-{
-	splitInstances = SPLIT;
-
-}
-
 
 /*
@@ -1601,2 +1593,12 @@
 }*/
 
+
+/*
+ * wxEVT_COMMAND_RADIOBUTTON_SELECTED event handler for Seperated_RadioButton
+ */
+
+void MainWindow::OnSeperatedRadioButtonSelected( wxCommandEvent& event )
+{
+splitInstances = SPLIT;
+}
+
Index: /AE/Installer/trunk/source/main_window.h
===================================================================
--- /AE/Installer/trunk/source/main_window.h	(revision 384)
+++ /AE/Installer/trunk/source/main_window.h	(revision 385)
@@ -57,5 +57,5 @@
 #define Sep_RadioButton 10013
 #define NoSep_RadioButton 10014
-#define Separated_RadioButton 10015
+#define Seperated_RadioButton 10015
 #define Complete_RadioButton 10016
 #define ReGlobalize_Button 10018
@@ -65,5 +65,5 @@
 #define SYMBOL_MAINWINDOW_TITLE _("Installer")
 #define SYMBOL_MAINWINDOW_IDNAME ID_MAINWINDOW
-#define SYMBOL_MAINWINDOW_SIZE wxSize(400, 500)
+#define SYMBOL_MAINWINDOW_SIZE wxSize(540, 500)
 #define SYMBOL_MAINWINDOW_POSITION wxDefaultPosition
 ////@end control identifiers
@@ -128,6 +128,6 @@
     void OnNoSepRadioButtonSelected( wxCommandEvent& event );
 
-    /// wxEVT_COMMAND_RADIOBUTTON_SELECTED event handler for Separated_RadioButton
-    void OnSeparatedRadioButtonSelected( wxCommandEvent& event );
+    /// wxEVT_COMMAND_RADIOBUTTON_SELECTED event handler for Seperated_RadioButton
+    void OnSeperatedRadioButtonSelected( wxCommandEvent& event );
 
     /// wxEVT_COMMAND_RADIOBUTTON_SELECTED event handler for Complete_RadioButton
@@ -180,5 +180,5 @@
     wxRadioButton* SepRadio;
     wxRadioButton* NoSepRadio;
-    wxRadioButton* SeparatedRadio;
+    wxRadioButton* SeperatedRadio;
     wxRadioButton* CompleteRadio;
     wxButton* ReglobalizeButton;
